.. _user_guide:

##########
User Guide
##########

.. toctree::
   :maxdepth: 2
   :caption: Get started

   installation

.. toctree::
    :maxdepth: 2
    :caption: DICOM concepts

    concepts_uids
    concepts_information_model
    concepts_ae
    concepts_contexts
    concepts_association

.. toctree::
   :maxdepth: 2
   :caption: Presentation contexts

   presentation_introduction
   presentation_private
   presentation_requestor
   presentation_acceptor
   presentation_negotiation
   presentation_role_selection

.. toctree::
   :maxdepth: 2
   :caption: Event handling

   events_types
   events_handlers

.. toctree::
   :maxdepth: 2
   :caption: Application Entity

   ae
   ae_scu
   ae_scp

.. toctree::
   :maxdepth: 2
   :caption: Association

   association_requesting
   association_accepting
